sqlobject.tests.test_ForeignKey module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_ForeignKey module

class `sqlobject.tests.test_ForeignKey.` `SOTestComposerKey`(**kw)

  Bases: `sqlobject.main.SQLObject`

  classmethod `byId2`(val, connection=None)
  property `id2`
  `j` = so_test_composer_key
  property `name`
  `q` = so_test_composer_key
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_ForeignKey.SOTestComposerKey`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_test_composer_key'

class `sqlobject.tests.test_ForeignKey.` `SOTestFKValidationA`(**kw)

  Bases: `sqlobject.main.SQLObject`

  property `bfk`
  property `bfkID`
  property `cfk`
  property `cfkID`
  `j` = so_test_fk_validation_a
  property `name`
  `q` = so_test_fk_validation_a
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_ForeignKey.SOTestFKValidationA`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_test_fk_validation_a'

class `sqlobject.tests.test_ForeignKey.` `SOTestFKValidationB`(**kw)

  Bases: `sqlobject.main.SQLObject`

  property `afk`
  property `afkID`
  `j` = so_test_fk_validation_b
  property `name`
  `q` = so_test_fk_validation_b
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_ForeignKey.SOTestFKValidationB`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_test_fk_validation_b'

class `sqlobject.tests.test_ForeignKey.` `SOTestFKValidationC`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = so_test_fk_validation_c
  property `name`
  `q` = so_test_fk_validation_c
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `idType`

      alias of `str`

    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_ForeignKey.SOTestFKValidationC`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_test_fk_validation_c'

class `sqlobject.tests.test_ForeignKey.` `SOTestOtherColumn`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = so_test_other_column
  property `key1`
  property `key1ID`
  property `key2`
  property `key2ID`
  `q` = so_test_other_column
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_ForeignKey.SOTestOtherColumn`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_test_other_column'

class `sqlobject.tests.test_ForeignKey.` `SOTestWorkKey`(**kw)

  Bases: `sqlobject.main.SQLObject`

  property `composer`
  property `composerID`
  `j` = so_test_work_key
  `q` = so_test_work_key
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'work_id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_ForeignKey.SOTestWorkKey`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_test_work_key'
  property `title`

class `sqlobject.tests.test_ForeignKey.` `SOTestWorkKey2`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = so_test_work_key2
  `q` = so_test_work_key2
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_ForeignKey.SOTestWorkKey2`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_test_work_key2'
  property `title`

`sqlobject.tests.test_ForeignKey.` `test1`()

`sqlobject.tests.test_ForeignKey.` `test2`()

`sqlobject.tests.test_ForeignKey.` `test_foreignkey_validation`()

`sqlobject.tests.test_ForeignKey.` `test_otherColumn`()